/***************** Laser cutter kerf calibration jig ***********************
* Consisting of nine sliding tiles (for ten cuts) in a frame.
* Slide all the tiles to one end of the frame and measure the gap at 
* the other end, and divide by ten to get the min. width of cut.
* Assuming a wedge shaped cut resulting in tilted edges, flip every
* other tile, starting with an end one to get them to pack closer
* to measure the max. width of cut as above.
* Mark one side before cutting to avoid inadvertant tile flipping.
* Apply masking tape or similar to keep parts in order when transferring
* from cutter bed to table!
*
* N.B. four of the tiles are generated as 'scrap' to avoid retracing 
* the cut line between the tiles which might widen the kerf.
* Min. X or Y should be three times the max. bed honeycomb cell dimension.
* The kerf will vary with laser focus, material type and thickness, and
* due to beam divergance, may vary with X and Y position on the bed,
* and with cut orientation.
*******************************************************************/

// 4mm ply 8mm speed 70%  min kerf=0.12 max kerf=0.155


include <BOSL2/std.scad>
/*[Tile Size]*/
X=10;
Y=20;
margin=5;
module __Customizer_Limit__ () {} // end customizer
$dd=0+1E-3;

render() // Only needed for preview on graphics cards with broken OpenGL
diff("x"){
square([9*X+2*margin,Y+2*margin], center=true);  //frame outline
xcopies(2*X,5) square([X,Y],center=true, $tag="x"); //tiles
ycopies(Y) square([9*X,$dd], center=true, $tag="x"); //top & bottom cuts    
}